@@ -23,6 +23,7 @@ from cdftpy.cdft1d.rdf import write_rdf_sim
 from cdftpy.cdft1d.rism_new import rism_1d
 from cdftpy.cdft1d.rsdft import rsdft_1d
 from cdftpy.cdft1d.solvent import solvent_model_locate, Solvent
+from cdftpy import __version__
 
 HEADER = """
 ==================================
@@ -164,11 +165,13 @@ def cdft1d_run_input(input_file, method):
     solvent_name = parameters["solvent"]
     filename = solvent_model_locate(solvent_name)
 
-    solvent = Solvent.from_file(filename, rism_patch=True)
+
 
     if method == "rism":
+        solvent = Solvent.from_file(filename, rism_patch=True)
         sim = rism_1d(solute, solvent, params=parameters)
     elif method == "rsdft":
+        solvent = Solvent.from_file(filename, rism_patch=False)
         sim = rsdft_1d(solute, solvent, params=parameters)
     else:
         print(f"Unknown method {theory}")
@@ -200,15 +203,15 @@ def rism1d_run_input(input_file):
 
     if input_file == "":
         input_file = cdft1d_generate_input()
-        cdft1d_run_input(input_file, "rism")
-    else:
-        cdft1d_run_input(input_file, "rism")
+
+    cdft1d_run_input(input_file, "rism")
 
 
 # noinspection PyTypeChecker
 @click.command()
 @click.argument("input_file", default="")
-def rsdft1d_run_input(input_file):
+@click.option("--version", is_flag=True)
+def rsdft1d_run_input(input_file, version):
     """
     Perform 1D RISM calculation
 
@@ -217,9 +220,11 @@ def rsdft1d_run_input(input_file):
 
 
     """
+    if version:
+        print(__version__)
+        sys.exit(0)
 
     if input_file == "":
         input_file = cdft1d_generate_input()
-        cdft1d_run_input(input_file, "rsdft")
-    else:
-        cdft1d_run_input(input_file, "rsdft")
+
+    cdft1d_run_input(input_file, "rsdft")
