@@ -21,6 +21,7 @@ def print_simulation(solute, solvent_model, params):
     print(f"   name {solvent_model.aname}")
     print(f"   file  {solvent_model.filename}")
     print(f"   ngrid {solvent_model.ifft.ngrid}")
+    print(f"   rmax {solvent_model.ifft.rgrid[-1]}")
     print(f"   density {solvent_model.density}")
     print(f"   temp {solvent_model.temp}")
 
@@ -161,7 +162,7 @@ def read_rism_patch(filename, section="rism_patch"):
     tag = f"<{section}>"
     with open(filename, "r") as fp:
         if find_section(tag, fp) is None:
-            print(f"cannot find {tag} section")
+            # print(f"cannot find {tag} section")
             return ff
         for line in iter_lines(fp):
             if line.startswith("<"):
@@ -195,7 +196,6 @@ def read_system(
         ff_rism = read_rism_patch(filename)
         for i, name in enumerate(system["atype"]):
             if name in ff_rism:
-                print("found", ff_rism[name])
                 sigma_list[i] = ff_rism[name]["sigma"]
                 eps_list[i] = ff_rism[name]["eps"]
 
@@ -298,6 +298,33 @@ def write_matrix_array(filename, grid, matrix, header=None):
                     fp.write(F"{matrix[i, j, k]}  ")
             fp.write("\n")
 
+def write_array(filename, grid, matrix, header=None):
+
+    ngrid = matrix.shape[-1]
+    nv = matrix.shape[0]
+
+    with open(filename,"w") as fp:
+        if header:
+            fp.write(F"#{header}\n")
+        for k in range(ngrid):
+            fp.write(F"{grid[k]}   ")
+            for i in range(nv):
+                    fp.write(F"{matrix[i, k]}  ")
+            fp.write("\n")
+
+def write_array1(filename, grid, matrix, header=None):
+
+    ngrid = matrix.shape[-1]
+    nv = matrix.shape[0]
+
+    with open(filename,"w") as fp:
+        if header:
+            fp.write(F"#{header}\n")
+        for k in range(ngrid):
+            fp.write(F"{grid[k]}   ")
+            fp.write(F"{matrix[k]}  ")
+            fp.write("\n")
+
 if __name__ == "__main__":
     filename = "/Users/marat/codes/cdft-dev/data/input.dat"
     print(read_solute(filename))
