@@ -9,21 +9,20 @@ import numpy as np
 from scipy.signal import argrelmax
 from scipy.signal import argrelmin
 
-from cdftpy.cdft1d.io_utils import print_banner
+from cdftpy.cdft1d.io_utils import print_banner, iter_lines
 
 
 def analyze_rdf_peaks_sim(sim):
-    analyze_rdf_peaks(sim.ifft, sim.solvent.aname, sim.h_r)
-
+    return analyze_rdf_peaks(sim.ifft, sim.solvent.aname, sim.h_r)
 
 def write_rdf_sim(sim, dir="./"):
     write_rdf(sim.ifft, sim.solute.name, sim.solvent.aname, sim.h_r, dir=dir)
 
-
 def analyze_rdf_peaks(ifft, nametag, h_r):
 
     rgrid = ifft.rgrid
 
+    peaks = {}
     print_banner("RDF Analysis")
     for i, name in enumerate(nametag):
         imax0 = np.argmax(h_r[i, :])
@@ -35,17 +34,23 @@ def analyze_rdf_peaks(ifft, nametag, h_r):
         imin_filter = imin > imax0
         imin0 = imin[imin_filter][0]
 
-        print(
-            f"{name} first  max height/position: {rgrid[imax0]:<.2f} {h_r[i, imax0] + 1:<.2f}  "
+        peaks[name] = dict(
+            first_peak = (h_r[i, imax0] + 1,rgrid[imax0]),
+            second_peak = (h_r[i, imax1] + 1, rgrid[imax1]),
+            first_min = (h_r[i, imin0] + 1, rgrid[imin0])
         )
         print(
-            f"{name} second max height/position: {rgrid[imax1]:<.2f} {h_r[i, imax1] + 1:<.2f}  "
+            f"{name} first  max position/height: {rgrid[imax0]:<.2f} {h_r[i, imax0] + 1:<.2f}  "
         )
         print(
-            f"{name} first  min height/position: {rgrid[imin0]:<.2f} {h_r[i, imin0] + 1:<.2f}  "
+            f"{name} second max position/height: {rgrid[imax1]:<.2f} {h_r[i, imax1] + 1:<.2f}  "
+        )
+        print(
+            f"{name} first  min position/height: {rgrid[imin0]:<.2f} {h_r[i, imin0] + 1:<.2f}  "
         )
         print("  ")
 
+    return peaks
 
 def write_rdf(ifft, solute_name, solvent_name, h_r, dir="./"):
 
